@@ -21,6 +21,7 @@ from .utils.xml_util import XMLUtil as XMLUtil
 from .utils.thread_util import ThreadUtil as ThreadUtil
 from .utils.func_util import FuncUtil as FuncUtil
 from .utils.package_util import PackageUtil as PackageUtil
+from .utils.exception_util import ExceptionUtil as ExceptionUtil
 
 try:
     from .utils.flask_util import FlaskUtil as FlaskUtil
@@ -66,4 +67,5 @@ __all__ = [
     'ThreadUtil',
     'FuncUtil',
     'PackageUtil',
+    'ExceptionUtil',
 ]
