@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, TypeVar, Optional
 from pathlib import Path
 from contextlib import contextmanager
 import sys
@@ -11,11 +11,20 @@ if TYPE_CHECKING:
     from _typeshed import FileDescriptorOrPath
 
 
+T = TypeVar('T')
+
+
 class PathUtil(object):
     """路径工具类"""
 
+    Path = Path
     sys_path = sys.path
 
+    @staticmethod
+    def get_env(key: str, default: Optional[T] = None) -> str | T:
+        """获取环境变量"""
+        return os.getenv(key, default)
+
     @staticmethod
     def get_work_dir() -> str:
         """获取工作目录"""
@@ -27,17 +36,15 @@ class PathUtil(object):
         os.chdir(path)
 
     @staticmethod
-    def get_project_root(root_name: str, join_path: str | None = None) -> str:
-        """返回项目根目录的绝对地址
+    def get_home_dir() -> Path:
+        """获取用户目录"""
+        return Path.home()
 
-        :param root_name 跟文件夹名称
-        :param join_path 拼接路径
-        """
-        root_path = __file__[:__file__.index(root_name) + len(root_name)]
-
-        if join_path:
-            return str(Path(root_path).joinpath(join_path))
-        return root_path
+    @staticmethod
+    def get_dir(path: str) -> Path:
+        """获取路径的目录"""
+        p = Path(path)
+        return p if p.is_dir() else p.parent
 
     @staticmethod
     def abspath(path: str = '') -> str:
